{$lang_fullpage_title}

- {$lang_fullpage_meta_tab}
- {$lang_fullpage_appearance_tab}
- {$lang_fullpage_advanced_tab}

{$lang_fullpage_meta_props}

{$lang_fullpage_meta_title} |
{$lang_fullpage_meta_keywords} |
{$lang_fullpage_meta_description} |
{$lang_fullpage_author} |
{$lang_fullpage_copyright} |
{$lang_fullpage_meta_robots} |

{$lang_fullpage_langprops}

{$lang_fullpage_encoding} |
{$lang_fullpage_doctypes} |
{$lang_fullpage_langcode} |
{$lang_fullpage_langdir} |
{$lang_fullpage_xml_pi} |

{$lang_fullpage_appearance_textprops}

{$lang_fullpage_fontface} |
{$lang_fullpage_fontsize} |
{$lang_fullpage_textcolor} |

{$lang_fullpage_appearance_bgprops}

{$lang_fullpage_bgimage} |
{$lang_fullpage_bgcolor} |

{$lang_fullpage_appearance_marginprops}

{$lang_fullpage_left_margin} |  | {$lang_fullpage_right_margin} |
{$lang_fullpage_top_margin} |  | {$lang_fullpage_bottom_margin} |

{$lang_fullpage_appearance_linkprops}

{$lang_fullpage_link_color} |
| {$lang_fullpage_visited_color} |
{$lang_fullpage_active_color} |

{$lang_fullpage_appearance_style}

{$lang_fullpage_stylesheet} |
{$lang_fullpage_style} |

{$lang_fullpage_add_title}
{$lang_fullpage_add_meta}
{$lang_fullpage_add_script}
{$lang_fullpage_add_style}
{$lang_fullpage_add_link}
{$lang_fullpage_add_base}
{$lang_fullpage_add_comment}

{$lang_fullpage_head_elements}
{$lang_fullpage_meta_element}

{$lang_fullpage_type} |
{$lang_fullpage_name} |
{$lang_fullpage_content} |

{$lang_fullpage_title_element}

{$lang_fullpage_meta_title} |

{$lang_fullpage_script_element}

- {$lang_fullpage_properties}
- {$lang_fullpage_value}

{$lang_fullpage_type} |
{$lang_fullpage_src} |
{$lang_fullpage_charset} |
{$lang_fullpage_defer} |

{$lang_fullpage_style_element}

- {$lang_fullpage_properties}
- {$lang_fullpage_value}

{$lang_fullpage_type} |
{$lang_fullpage_media} |

{$lang_fullpage_base_element}

{$lang_fullpage_href} |
{$lang_fullpage_target} |

{$lang_fullpage_link_element}

- {$lang_fullpage_general_props}
- {$lang_fullpage_advanced_props}

{$lang_fullpage_href} |
{$lang_fullpage_meta_title} |
{$lang_fullpage_type} |
{$lang_fullpage_media} |
{$lang_fullpage_rel} |

{$lang_fullpage_charset} |
{$lang_fullpage_hreflang} |
{$lang_fullpage_target} |
{$lang_fullpage_rev} |

{$lang_fullpage_comment_element}